@@ -22,6 +22,8 @@ import { getNumber, randomStr } from "../../../../utils";
 import DomainInput from "../../Common/DomainInput";
 import SizeInput from "../../Common/SizeInput";
 import MagicVar from "../../Dialogs/MagicVar";
+import { Trans, useTranslation } from "react-i18next";
+import { transformPolicyRequest } from "../utils";
 
 const useStyles = makeStyles((theme) => ({
     stepContent: {
@@ -90,28 +92,29 @@ const useStyles = makeStyles((theme) => ({
 
 const steps = [
     {
-        title: "存储端配置",
+        title: "storageNode",
         optional: false,
     },
     {
-        title: "上传路径",
+        title: "storagePathStep",
         optional: false,
     },
     {
-        title: "直链设置",
+        title: "sourceLinkStep",
         optional: false,
     },
     {
-        title: "上传设置",
+        title: "uploadSettingStep",
         optional: false,
     },
     {
-        title: "完成",
+        title: "finishStep",
         optional: false,
     },
 ];
 
 export default function RemoteGuide(props) {
+    const { t } = useTranslation("dashboard", { keyPrefix: "policy" });
     const classes = useStyles();
     const history = useHistory();
 
@@ -179,7 +182,7 @@ export default function RemoteGuide(props) {
             secret: policy.SecretKey,
         })
             .then(() => {
-                ToggleSnackbar("top", "right", "通信正常", "success");
+                ToggleSnackbar("top", "right", t("communicationOK"), "success");
             })
             .catch((error) => {
                 ToggleSnackbar("top", "right", error.message, "error");
@@ -193,7 +196,7 @@ export default function RemoteGuide(props) {
         e.preventDefault();
         setLoading(true);
 
-        const policyCopy = { ...policy };
+        let policyCopy = { ...policy };
         policyCopy.OptionsSerialized = { ...policyCopy.OptionsSerialized };
 
         // 处理存储策略
@@ -202,25 +205,7 @@ export default function RemoteGuide(props) {
         }
 
         // 类型转换
-        policyCopy.AutoRename = policyCopy.AutoRename === "true";
-        policyCopy.IsOriginLinkEnable =
-            policyCopy.IsOriginLinkEnable === "true";
-        policyCopy.MaxSize = parseInt(policyCopy.MaxSize);
-        policyCopy.OptionsSerialized.chunk_size = parseInt(
-            policyCopy.OptionsSerialized.chunk_size
-        );
-        policyCopy.OptionsSerialized.placeholder_with_size =
-            policyCopy.OptionsSerialized.placeholder_with_size === "true";
-        policyCopy.IsPrivate = policyCopy.IsPrivate === "true";
-        policyCopy.OptionsSerialized.file_type = policyCopy.OptionsSerialized.file_type.split(
-            ","
-        );
-        if (
-            policyCopy.OptionsSerialized.file_type.length === 1 &&
-            policyCopy.OptionsSerialized.file_type[0] === ""
-        ) {
-            policyCopy.OptionsSerialized.file_type = [];
-        }
+        policyCopy = transformPolicyRequest(policyCopy);
 
         API.post("/admin/policy", {
             policy: policyCopy,
@@ -229,7 +214,7 @@ export default function RemoteGuide(props) {
                 ToggleSnackbar(
                     "top",
                     "right",
-                    "存储策略已" + (props.policy ? "保存" : "添加"),
+                    props.policy ? t("policySaved") : t("policyAdded"),
                     "success"
                 );
                 setActiveStep(5);
@@ -247,7 +232,9 @@ export default function RemoteGuide(props) {
     return (
         <div>
             <Typography variant={"h6"}>
-                {props.policy ? "修改" : "添加"}从机存储策略
+                {props.policy
+                    ? t("editRemoteStoragePolicy")
+                    : t("addRemoteStoragePolicy")}
             </Typography>
             <Stepper activeStep={activeStep}>
                 {steps.map((label, index) => {
@@ -255,7 +242,9 @@ export default function RemoteGuide(props) {
                     const labelProps = {};
                     if (label.optional) {
                         labelProps.optional = (
-                            <Typography variant="caption">可选</Typography>
+                            <Typography variant="caption">
+                                {t("optional")}
+                            </Typography>
                         );
                     }
                     if (isStepSkipped(index)) {
@@ -263,7 +252,9 @@ export default function RemoteGuide(props) {
                     }
                     return (
                         <Step key={label.title} {...stepProps}>
-                            <StepLabel {...labelProps}>{label.title}</StepLabel>
+                            <StepLabel {...labelProps}>
+                                {t(label.title)}
+                            </StepLabel>
                         </Step>
                     );
                 })}
@@ -278,8 +269,7 @@ export default function RemoteGuide(props) {
                     }}
                 >
                     <Alert severity="info" style={{ marginBottom: 10 }}>
-                        从机存储策略允许你使用同样运行了 Cloudreve
-                        的服务器作为存储端， 用户上传下载流量通过 HTTP 直传。
+                        {t("remoteDescription")}
                     </Alert>
 
                     <div className={classes.subStepContainer}>
@@ -288,8 +278,7 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                将和主站相同版本的 Cloudreve
-                                程序拷贝至要作为从机的服务器上。
+                                {t("remoteCopyBinaryDescription")}
                             </Typography>
                         </div>
                     </div>
@@ -300,13 +289,12 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                下方为系统为您随机生成的从机端密钥，一般无需改动，如果有自定义需求，
-                                可将您的密钥填入下方：
+                                {t("remoteSecretDescription")}
                             </Typography>
                             <div className={classes.form}>
                                 <FormControl fullWidth>
                                     <InputLabel htmlFor="component-helper">
-                                        从机密钥
+                                        {t("remoteSecret")}
                                     </InputLabel>
                                     <Input
                                         required
@@ -327,12 +315,13 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                修改从机配置文件。
+                                {t("modifyRemoteConfig")}
                                 <br />
-                                在从机端 Cloudreve 的同级目录下新建
-                                <code>conf.ini</code>
-                                文件，填入从机配置，启动/重启从机端 Cloudreve。
-                                以下为一个可供参考的配置例子，其中密钥部分已帮您填写为上一步所生成的。
+                                <Trans
+                                    ns={"dashboard"}
+                                    i18nKey={"policy.addRemoteConfigDes"}
+                                    components={[<code key={0} />]}
+                                />
                             </Typography>
                             <pre>
                                 [System]
@@ -355,24 +344,41 @@ export default function RemoteGuide(props) {
                                 AllowHeaders = *<br />
                             </pre>
                             <Typography variant={"body2"}>
-                                从机端配置文件格式大致与主站端相同，区别在于：
+                                {t("remoteConfigDifference")}
                                 <ul>
                                     <li>
-                                        <code>System</code>
-                                        分区下的
-                                        <code>mode</code>
-                                        字段必须更改为<code>slave</code>
+                                        <Trans
+                                            ns={"dashboard"}
+                                            i18nKey={
+                                                "policy.remoteConfigDifference1"
+                                            }
+                                            components={[
+                                                <code key={0} />,
+                                                <code key={1} />,
+                                                <code key={2} />,
+                                            ]}
+                                        />
                                     </li>
                                     <li>
-                                        必须指定<code>Slave</code>分区下的
-                                        <code>Secret</code>
-                                        字段，其值为第二步里填写或生成的密钥。
+                                        <Trans
+                                            ns={"dashboard"}
+                                            i18nKey={
+                                                "policy.remoteConfigDifference2"
+                                            }
+                                            components={[
+                                                <code key={0} />,
+                                                <code key={1} />,
+                                            ]}
+                                        />
                                     </li>
                                     <li>
-                                        必须启动跨域配置，即<code>CORS</code>
-                                        字段的内容，
-                                        具体可参考上文范例或官方文档。如果配置不正确，用户将无法通过
-                                        Web 端向从机上传文件。
+                                        <Trans
+                                            ns={"dashboard"}
+                                            i18nKey={
+                                                "policy.remoteConfigDifference3"
+                                            }
+                                            components={[<code key={0} />]}
+                                        />
                                     </li>
                                 </ul>
                             </Typography>
@@ -385,16 +391,14 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                填写从机地址。
+                                {t("inputRemoteAddress")}
                                 <br />
-                                如果主站启用了
-                                HTTPS，从机也需要启用，并在下方填入 HTTPS
-                                协议的地址。
+                                {t("inputRemoteAddressDes")}
                             </Typography>
                             <div className={classes.form}>
                                 <FormControl fullWidth>
                                     <InputLabel htmlFor="component-helper">
-                                        从机地址
+                                        {t("remoteAddress")}
                                     </InputLabel>
                                     <Input
                                         fullWidth
@@ -414,7 +418,7 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                完成以上步骤后，你可以点击下方的测试按钮测试通信是否正常。
+                                {t("testCommunicationDes")}
                             </Typography>
                             <div className={classes.form}>
                                 <Button
@@ -423,7 +427,7 @@ export default function RemoteGuide(props) {
                                     variant={"outlined"}
                                     color={"primary"}
                                 >
-                                    测试从机通信
+                                    {t("testCommunication")}
                                 </Button>
                             </div>
                         </div>
@@ -436,7 +440,7 @@ export default function RemoteGuide(props) {
                             variant={"contained"}
                             color={"primary"}
                         >
-                            下一步
+                            {t("next")}
                         </Button>
                     </div>
                 </form>
@@ -456,25 +460,23 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                请在下方输入文件的存储目录路径，可以为绝对路径或相对路径（相对于
-                                从机的
-                                Cloudreve）。路径中可以使用魔法变量，文件在上传时会自动替换这些变量为相应值；
-                                可用魔法变量可参考{" "}
-                                <Link
-                                    color={"secondary"}
-                                    onClick={(e) => {
-                                        e.preventDefault();
-                                        setMagicVar("path");
-                                    }}
-                                >
-                                    路径魔法变量列表
-                                </Link>{" "}
-                                。
+                                <Trans
+                                    ns={"dashboard"}
+                                    i18nKey={"policy.filePathMagicVarDes"}
+                                    components={[
+                                        <Link
+                                            key={0}
+                                            color={"secondary"}
+                                            href={"javascript:void()"}
+                                            onClick={() => setMagicVar("file")}
+                                        />,
+                                    ]}
+                                />
                             </Typography>
                             <div className={classes.form}>
                                 <FormControl fullWidth>
                                     <InputLabel htmlFor="component-helper">
-                                        存储目录
+                                        {t("pathOfFolderToStoreFiles")}
                                     </InputLabel>
                                     <Input
                                         required
@@ -520,14 +522,14 @@ export default function RemoteGuide(props) {
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="开启重命名"
+                                            label={t("autoRenameStoredFile")}
                                         />
                                         <FormControlLabel
                                             value={"false"}
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="不开启"
+                                            label={t("keepOriginalFileName")}
                                         />
                                     </RadioGroup>
                                 </FormControl>
@@ -537,7 +539,7 @@ export default function RemoteGuide(props) {
                                 <div className={classes.form}>
                                     <FormControl fullWidth>
                                         <InputLabel htmlFor="component-helper">
-                                            命名规则
+                                            {t("renameRule")}
                                         </InputLabel>
                                         <Input
                                             required={
@@ -560,7 +562,7 @@ export default function RemoteGuide(props) {
                             className={classes.button}
                             onClick={() => setActiveStep(0)}
                         >
-                            上一步
+                            {t("back")}
                         </Button>
                         <Button
                             disabled={loading}
@@ -568,7 +570,7 @@ export default function RemoteGuide(props) {
                             variant={"contained"}
                             color={"primary"}
                         >
-                            下一步
+                            {t("next")}
                         </Button>
                     </div>
                 </form>
@@ -588,9 +590,9 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                是否允许获取文件永久直链？
+                                {t("enableGettingPermanentSourceLink")}
                                 <br />
-                                开启后，用户可以请求获得能直接访问到文件内容的直链，适用于图床应用或自用。
+                                {t("enableGettingPermanentSourceLinkDes")}
                             </Typography>
 
                             <div className={classes.form}>
@@ -608,14 +610,14 @@ export default function RemoteGuide(props) {
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="允许"
+                                            label={t("allowed")}
                                         />
                                         <FormControlLabel
                                             value={"false"}
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="禁止"
+                                            label={t("forbidden")}
                                         />
                                     </RadioGroup>
                                 </FormControl>
@@ -630,10 +632,9 @@ export default function RemoteGuide(props) {
                             </div>
                             <div className={classes.subStepContent}>
                                 <Typography variant={"body2"}>
-                                    是否要对下载/直链使用 CDN？
+                                    {t("useCDN")}
                                     <br />
-                                    开启后，用户访问文件时的 URL
-                                    中的域名部分会被替换为 CDN 域名。
+                                    {t("useCDNDes")}
                                 </Typography>
 
                                 <div className={classes.form}>
@@ -659,14 +660,14 @@ export default function RemoteGuide(props) {
                                                 control={
                                                     <Radio color={"primary"} />
                                                 }
-                                                label="使用"
+                                                label={t("use")}
                                             />
                                             <FormControlLabel
                                                 value={"false"}
                                                 control={
                                                     <Radio color={"primary"} />
                                                 }
-                                                label="不使用"
+                                                label={t("notUse")}
                                             />
                                         </RadioGroup>
                                     </FormControl>
@@ -681,7 +682,7 @@ export default function RemoteGuide(props) {
                                 </div>
                                 <div className={classes.subStepContent}>
                                     <Typography variant={"body2"}>
-                                        选择协议并填写 CDN 域名
+                                        {t("cdnDomain")}
                                     </Typography>
 
                                     <div className={classes.form}>
@@ -692,7 +693,7 @@ export default function RemoteGuide(props) {
                                                 policy.IsOriginLinkEnable ===
                                                     "true" && useCDN === "true"
                                             }
-                                            label={"CDN 前缀"}
+                                            label={t("cdnPrefix")}
                                         />
                                     </div>
                                 </div>
@@ -706,7 +707,7 @@ export default function RemoteGuide(props) {
                             className={classes.button}
                             onClick={() => setActiveStep(1)}
                         >
-                            上一步
+                            {t("back")}
                         </Button>{" "}
                         <Button
                             disabled={loading}
@@ -714,7 +715,7 @@ export default function RemoteGuide(props) {
                             variant={"contained"}
                             color={"primary"}
                         >
-                            下一步
+                            {t("next")}
                         </Button>
                     </div>
                 </form>
@@ -734,7 +735,7 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                是否限制上传的单文件大小？
+                                {t("limitFileSize")}
                             </Typography>
 
                             <div className={classes.form}>
@@ -766,14 +767,14 @@ export default function RemoteGuide(props) {
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="限制"
+                                            label={t("limit")}
                                         />
                                         <FormControlLabel
                                             value={"false"}
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="不限制"
+                                            label={t("notLimit")}
                                         />
                                     </RadioGroup>
                                 </FormControl>
@@ -788,7 +789,7 @@ export default function RemoteGuide(props) {
                             </div>
                             <div className={classes.subStepContent}>
                                 <Typography variant={"body2"}>
-                                    输入限制：
+                                    {t("enterSizeLimit")}
                                 </Typography>
                                 <div className={classes.form}>
                                     <SizeInput
@@ -796,7 +797,7 @@ export default function RemoteGuide(props) {
                                         onChange={handleChange("MaxSize")}
                                         min={0}
                                         max={9223372036854775807}
-                                        label={"单文件大小限制"}
+                                        label={t("maxSizeOfSingleFile")}
                                     />
                                 </div>
                             </div>
@@ -811,7 +812,7 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                是否限制上传文件扩展名？
+                                {t("limitFileExt")}
                             </Typography>
 
                             <div className={classes.form}>
@@ -851,14 +852,14 @@ export default function RemoteGuide(props) {
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="限制"
+                                            label={t("limit")}
                                         />
                                         <FormControlLabel
                                             value={"false"}
                                             control={
                                                 <Radio color={"primary"} />
                                             }
-                                            label="不限制"
+                                            label={t("notLimit")}
                                         />
                                     </RadioGroup>
                                 </FormControl>
@@ -875,13 +876,12 @@ export default function RemoteGuide(props) {
                             </div>
                             <div className={classes.subStepContent}>
                                 <Typography variant={"body2"}>
-                                    输入允许上传的文件扩展名，多个请以半角逗号 ,
-                                    隔开
+                                    {t("enterFileExt")}
                                 </Typography>
                                 <div className={classes.form}>
                                     <FormControl fullWidth>
                                         <InputLabel htmlFor="component-helper">
-                                            扩展名列表
+                                            {t("extList")}
                                         </InputLabel>
                                         <Input
                                             value={
@@ -909,10 +909,9 @@ export default function RemoteGuide(props) {
                         </div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                请指定分片上传时的分片大小，填写为 0
-                                表示不使用分片上传。
+                                {t("chunkSizeLabel")}
                                 <br />
-                                启用分片上传后，用户上传的文件将会被切分成分片逐个上传到存储端，当上传中断后，用户可以选择从上次上传的分片后继续开始上传。
+                                {t("chunkSizeDes")}
                             </Typography>
                             <div className={classes.form}>
                                 <SizeInput
@@ -920,7 +919,7 @@ export default function RemoteGuide(props) {
                                     onChange={handleOptionChange("chunk_size")}
                                     min={0}
                                     max={9223372036854775807}
-                                    label={"分片上传大小"}
+                                    label={t("chunkSize")}
                                 />
                             </div>
                         </div>
@@ -932,7 +931,7 @@ export default function RemoteGuide(props) {
                             className={classes.button}
                             onClick={() => setActiveStep(2)}
                         >
-                            上一步
+                            {t("back")}
                         </Button>{" "}
                         <Button
                             disabled={loading}
@@ -940,7 +939,7 @@ export default function RemoteGuide(props) {
                             variant={"contained"}
                             color={"primary"}
                         >
-                            下一步
+                            {t("next")}
                         </Button>
                     </div>
                 </form>
@@ -952,12 +951,12 @@ export default function RemoteGuide(props) {
                         <div className={classes.stepNumberContainer}></div>
                         <div className={classes.subStepContent}>
                             <Typography variant={"body2"}>
-                                最后一步，为此存储策略命名：
+                                {t("nameThePolicy")}
                             </Typography>
                             <div className={classes.form}>
                                 <FormControl fullWidth>
                                     <InputLabel htmlFor="component-helper">
-                                        存储策略名
+                                        {t("policyName")}
                                     </InputLabel>
                                     <Input
                                         required
@@ -974,7 +973,7 @@ export default function RemoteGuide(props) {
                             className={classes.button}
                             onClick={() => setActiveStep(3)}
                         >
-                            上一步
+                            {t("back")}
                         </Button>{" "}
                         <Button
                             disabled={loading}
@@ -982,7 +981,7 @@ export default function RemoteGuide(props) {
                             variant={"contained"}
                             color={"primary"}
                         >
-                            完成
+                            {t("finish")}
                         </Button>
                     </div>
                 </form>
@@ -992,10 +991,10 @@ export default function RemoteGuide(props) {
                 <>
                     <form className={classes.stepContent}>
                         <Typography>
-                            存储策略已{props.policy ? "保存" : "添加"}！
+                            {props.policy ? t("policySaved") : t("policyAdded")}
                         </Typography>
                         <Typography variant={"body2"} color={"textSecondary"}>
-                            要使用此存储策略，请到用户组管理页面，为相应用户组绑定此存储策略。
+                            {t("furtherActions")}
                         </Typography>
                     </form>
                     <div className={classes.stepFooter}>
@@ -1004,7 +1003,7 @@ export default function RemoteGuide(props) {
                             className={classes.button}
                             onClick={() => history.push("/admin/policy")}
                         >
-                            返回存储策略列表
+                            {t("backToList")}
                         </Button>
                     </div>
                 </>
