@@ -15,6 +15,8 @@ import FormControlLabel from "@material-ui/core/FormControlLabel";
 import Switch from "@material-ui/core/Switch";
 import { Trans, useTranslation } from "react-i18next";
 import Link from "@material-ui/core/Link";
+import ThumbGenerators from "./ThumbGenerators";
+import PolicySelector from "../Common/PolicySelector";
 
 const useStyles = makeStyles((theme) => ({
     root: {
@@ -58,6 +60,20 @@ export default function ImageSetting() {
         wopi_enabled: "0",
         wopi_endpoint: "",
         wopi_session_timeout: "0",
+        thumb_builtin_enabled: "0",
+        thumb_vips_enabled: "0",
+        thumb_vips_exts: "",
+        thumb_ffmpeg_enabled: "0",
+        thumb_vips_path: "",
+        thumb_ffmpeg_path: "",
+        thumb_ffmpeg_exts: "",
+        thumb_ffmpeg_seek: "",
+        thumb_libreoffice_path: "",
+        thumb_libreoffice_enabled: "0",
+        thumb_libreoffice_exts: "",
+        thumb_proxy_enabled: "0",
+        thumb_proxy_policy: [],
+        thumb_max_src_size: "",
     });
 
     const handleChange = (name) => (event) => {
@@ -79,6 +95,11 @@ export default function ImageSetting() {
             keys: Object.keys(options),
         })
             .then((response) => {
+                response.data.thumb_proxy_policy = JSON.parse(
+                    response.data.thumb_proxy_policy
+                ).map((v) => {
+                    return v.toString();
+                });
                 setOptions(response.data);
             })
             .catch((error) => {
@@ -103,9 +124,14 @@ export default function ImageSetting() {
         setLoading(true);
         const option = [];
         Object.keys(options).forEach((k) => {
+            let value = options[k];
+            if (k === "thumb_proxy_policy") {
+                value = JSON.stringify(value.map((v) => parseInt(v)));
+            }
+
             option.push({
                 key: k,
-                value: options[k],
+                value,
             });
         });
         API.patch("/admin/setting", {
@@ -388,12 +414,26 @@ export default function ImageSetting() {
                     <Typography variant="h6" gutterBottom>
                         {t("thumbnails")}
                     </Typography>
+                    <div className={classes.form}>
+                        <Alert severity="info">
+                            <Trans
+                                ns={"dashboard"}
+                                i18nKey={"settings.thumbnailDoc"}
+                                components={[
+                                    <Link
+                                        key={0}
+                                        target={"_blank"}
+                                        href={t("thumbnailDocLink")}
+                                    />,
+                                ]}
+                            />
+                        </Alert>
+                    </div>
+                    <Typography variant="subtitle1" gutterBottom>
+                        {t("thumbnailBasic")}
+                    </Typography>
 
                     <div className={classes.formContainer}>
-                        <div className={classes.form}>
-                            <Alert severity="info">{t("localOnlyInfo")}</Alert>
-                        </div>
-
                         <div className={classes.form}>
                             <FormControl>
                                 <InputLabel htmlFor="component-helper">
@@ -510,6 +550,26 @@ export default function ImageSetting() {
                             </FormControl>
                         </div>
 
+                        <div className={classes.form}>
+                            <FormControl fullWidth>
+                                {options.thumb_max_src_size !== "" && (
+                                    <SizeInput
+                                        value={options.thumb_max_src_size}
+                                        onChange={handleChange(
+                                            "thumb_max_src_size"
+                                        )}
+                                        required
+                                        min={0}
+                                        max={2147483647}
+                                        label={t("thumbMaxSize")}
+                                    />
+                                )}
+                                <FormHelperText id="component-helper-text">
+                                    {t("thumbMaxSizeDes")}
+                                </FormHelperText>
+                            </FormControl>
+                        </div>
+
                         <div className={classes.form}>
                             <FormControl fullWidth>
                                 <FormControlLabel
@@ -529,6 +589,63 @@ export default function ImageSetting() {
                             </FormControl>
                         </div>
                     </div>
+
+                    <Typography variant="subtitle1" gutterBottom>
+                        {t("generators")}
+                    </Typography>
+                    <div className={classes.formContainer}>
+                        <div className={classes.form}>
+                            <ThumbGenerators
+                                options={options}
+                                setOptions={setOptions}
+                            />
+                        </div>
+                    </div>
+
+                    <Typography variant="subtitle1" gutterBottom>
+                        {t("generatorProxy")}
+                    </Typography>
+                    <div className={classes.formContainer}>
+                        <div className={classes.form}>
+                            <Alert severity="info">
+                                {t("generatorProxyWarning")}
+                            </Alert>
+                        </div>
+
+                        <div className={classes.form}>
+                            <FormControl fullWidth>
+                                <FormControlLabel
+                                    control={
+                                        <Switch
+                                            checked={
+                                                options.thumb_proxy_enabled ===
+                                                "1"
+                                            }
+                                            onChange={handleCheckChange(
+                                                "thumb_proxy_enabled"
+                                            )}
+                                        />
+                                    }
+                                    label={t("enableThumbProxy")}
+                                />
+                            </FormControl>
+                        </div>
+                        {options.thumb_proxy_enabled === "1" && (
+                            <>
+                                <div className={classes.form}>
+                                    <PolicySelector
+                                        value={options.thumb_proxy_policy}
+                                        onChange={handleChange(
+                                            "thumb_proxy_policy"
+                                        )}
+                                        filter={(t) => t.Type !== "local"}
+                                        label={t("proxyPolicyList")}
+                                        helperText={t("proxyPolicyListDes")}
+                                    />
+                                </div>
+                            </>
+                        )}
+                    </div>
                 </div>
 
                 <div className={classes.root}>
