@@ -3,6 +3,7 @@ import Backdrop from "@material-ui/core/Backdrop";
 import { createStyles, makeStyles } from "@material-ui/core/styles";
 import UploadIcon from "@material-ui/icons/CloudUpload";
 import { Typography } from "@material-ui/core";
+import { useTranslation } from "react-i18next";
 
 const useStyles = makeStyles((theme) =>
     createStyles({
@@ -16,13 +17,16 @@ const useStyles = makeStyles((theme) =>
 
 export function DropFileBackground({ open }) {
     const classes = useStyles();
+    const { t } = useTranslation();
     return (
         <Backdrop className={classes.backdrop} open={open}>
             <div>
                 <UploadIcon style={{ fontSize: 80 }} />
             </div>
             <div>
-                <Typography variant={"h4"}>松开鼠标开始上传</Typography>
+                <Typography variant={"h4"}>
+                    {t("uploader.dropFileHere")}
+                </Typography>
             </div>
         </Backdrop>
     );
