@@ -13,10 +13,12 @@ import {
     openMusicDialog,
     openResaveDialog,
     setSelectedTarget,
+    showAudioPreview,
     showImgPreivew,
     toggleSnackbar,
 } from "../../redux/explorer";
 import { startDownload } from "../../redux/explorer/action";
+import { withTranslation } from "react-i18next";
 
 vhCheck();
 const styles = (theme) => ({
@@ -64,7 +66,7 @@ const styles = (theme) => ({
         width: "100%",
         maxWidth: 440,
         backgroundColor: theme.palette.background.paper,
-        borderRadius: 12,
+        borderRadius: theme.shape.borderRadius,
         boxShadow: "0 8px 16px rgba(29,39,55,.25)",
         [theme.breakpoints.down("sm")]: {
             height: "calc(var(--vh, 100vh) - 56px)",
@@ -104,8 +106,8 @@ const mapDispatchToProps = (dispatch) => {
         toggleSnackbar: (vertical, horizontal, msg, color) => {
             dispatch(toggleSnackbar(vertical, horizontal, msg, color));
         },
-        openMusicDialog: () => {
-            dispatch(openMusicDialog());
+        openMusicDialog: (first) => {
+            dispatch(showAudioPreview(first));
         },
         setSelectedTarget: (targets) => {
             dispatch(setSelectedTarget(targets));
@@ -143,7 +145,7 @@ class SharedFileCompoment extends Component {
                 this.props.toggleSnackbar(
                     "top",
                     "right",
-                    "请先登录",
+                    this.props.t("share.pleaseLogin"),
                     "warning"
                 );
                 return;
@@ -165,13 +167,11 @@ class SharedFileCompoment extends Component {
                 );
                 return;
             case "audio":
-                this.props.setSelectedTarget([
-                    {
-                        key: this.props.share.key,
-                        type: "share",
-                    },
-                ]);
-                this.props.openMusicDialog();
+                this.props.openMusicDialog({
+                    key: this.props.share.key,
+                    name: this.props.share.source.name,
+                    type: "share",
+                });
                 return;
             case "video":
                 this.props.history.push(
@@ -212,7 +212,7 @@ class SharedFileCompoment extends Component {
                 this.props.toggleSnackbar(
                     "top",
                     "right",
-                    "此文件无法预览",
+                    this.props.t("share.cannotShare"),
                     "warning"
                 );
                 return;
@@ -232,7 +232,7 @@ class SharedFileCompoment extends Component {
     };
 
     render() {
-        const { classes } = this.props;
+        const { classes, t } = this.props;
         return (
             <div className={classes.layout}>
                 <Modals />
@@ -265,7 +265,7 @@ class SharedFileCompoment extends Component {
                                     onClick={this.scoreHandle(this.preview)}
                                     disabled={this.state.loading}
                                 >
-                                    预览
+                                    {t("share.preview")}
                                 </Button>
                             )}
                         </div>
@@ -277,7 +277,7 @@ class SharedFileCompoment extends Component {
                                 onClick={this.download}
                                 disabled={this.state.loading}
                             >
-                                下载
+                                {t("fileManager.download")}
                             </Button>
                         </div>
                     </div>
@@ -290,6 +290,6 @@ class SharedFileCompoment extends Component {
 const SharedFile = connect(
     mapStateToProps,
     mapDispatchToProps
-)(withStyles(styles)(withRouter(SharedFileCompoment)));
+)(withStyles(styles)(withRouter(withTranslation()(SharedFileCompoment))));
 
 export default SharedFile;
