@@ -51,7 +51,21 @@ export const codePreviewSuffix = {
 export const mediaType = {
     audio: ["mp3", "flac", "ape", "wav", "acc", "ogg", "m4a"],
     video: ["mp4", "flv", "avi", "wmv", "mkv", "rm", "rmvb", "mov", "ogv"],
-    image: ["bmp", "iff", "png", "gif", "jpg", "jpeg", "psd", "svg", "webp"],
+    image: [
+        "bmp",
+        "iff",
+        "png",
+        "gif",
+        "jpg",
+        "jpeg",
+        "psd",
+        "svg",
+        "webp",
+        "heif",
+        "heic",
+        "tiff",
+        "avif",
+    ],
     pdf: ["pdf"],
     word: ["doc", "docx"],
     ppt: ["ppt", "pptx"],
