@@ -7,15 +7,24 @@ import React, {
 } from "react";
 import { useDispatch } from "react-redux";
 import API from "../middleware/Api";
-import { FormControl, Input, InputLabel } from "@material-ui/core";
+import {
+    FormControl,
+    Input,
+    InputAdornment,
+    InputLabel,
+    makeStyles,
+    TextField,
+} from "@material-ui/core";
 import Placeholder from "../component/Placeholder/Captcha";
 import { defaultValidate, useStyle } from "./useCaptcha";
 import { toggleSnackbar } from "../redux/explorer";
+import { useTranslation } from "react-i18next";
 
 const NormalCaptcha = forwardRef(function NormalCaptcha(
     { captchaRef, setLoading },
     ref
 ) {
+    const { t } = useTranslation();
     const classes = useStyle();
 
     const [captcha, setCaptcha] = useState("");
@@ -38,7 +47,7 @@ const NormalCaptcha = forwardRef(function NormalCaptcha(
                 ToggleSnackbar(
                     "top",
                     "right",
-                    "无法加载验证码：" + error.message,
+                    t("login.captchaError", { message: error.message }),
                     "error"
                 );
             });
@@ -54,32 +63,40 @@ const NormalCaptcha = forwardRef(function NormalCaptcha(
     }, [captcha]);
 
     return (
-        <div className={classes.captchaContainer}>
+        <div className={classes.captchaInputContainer}>
             <FormControl margin="normal" required fullWidth>
-                <InputLabel htmlFor="captcha">验证码</InputLabel>
-                <Input
-                    name="captcha"
+                <TextField
+                    variant={"outlined"}
+                    label={t("login.captcha")}
+                    inputProps={{
+                        name: "captcha",
+                        id: "captcha",
+                    }}
                     onChange={(e) => setCaptcha(e.target.value)}
-                    type="text"
-                    id="captcha"
                     value={captcha}
                     autoComplete
+                    InputProps={{
+                        endAdornment: (
+                            <InputAdornment position={"end"}>
+                                <div
+                                    className={classes.captchaImageContainer}
+                                    title={t("login.clickToRefresh")}
+                                >
+                                    {captchaData === null && <Placeholder />}
+                                    {captchaData !== null && (
+                                        <img
+                                            className={classes.captchaImage}
+                                            src={captchaData}
+                                            alt="captcha"
+                                            onClick={refreshCaptcha}
+                                        />
+                                    )}
+                                </div>
+                            </InputAdornment>
+                        ),
+                    }}
                 />
             </FormControl>{" "}
-            <div>
-                {captchaData === null && (
-                    <div className={classes.captchaPlaceholder}>
-                        <Placeholder />
-                    </div>
-                )}
-                {captchaData !== null && (
-                    <img
-                        src={captchaData}
-                        alt="captcha"
-                        onClick={refreshCaptcha}
-                    />
-                )}
-            </div>
         </div>
     );
 });
