@@ -168,9 +168,10 @@ export const openRemoteDownloadDialog = () => {
         type: "OPEN_REMOTE_DOWNLOAD_DIALOG",
     };
 };
-export const openTorrentDownloadDialog = () => {
+export const openTorrentDownloadDialog = (selected) => {
     return {
         type: "OPEN_TORRENT_DOWNLOAD_DIALOG",
+        selected:selected,
     };
 };
 export const openDecompressDialog = () => {
@@ -281,3 +282,12 @@ export const setSiteConfig = (config) => {
         config: config,
     };
 };
+
+export const openDirectoryDownloadDialog = (downloading, log, done) => {
+    return {
+        type: "OPEN_DIRECTORY_DOWNLOAD_DIALOG",
+        downloading,
+        log,
+        done,
+    };
+};
