@@ -161,3 +161,12 @@ export const removeI18nCache = () => {
         }
     });
 };
+
+export const getSelectItemStyles = (name, personName, theme) => {
+    return {
+        fontWeight:
+            personName.indexOf(name) === -1
+                ? theme.typography.fontWeightRegular
+                : theme.typography.fontWeightMedium,
+    };
+};
\ No newline at end of file
