@@ -1,6 +1,8 @@
 package middleware
 
 import (
+	"github.com/cloudreve/Cloudreve/v3/pkg/cache"
+	"github.com/cloudreve/Cloudreve/v3/pkg/sessionstore"
 	"net/http"
 	"strings"
 
@@ -8,28 +10,16 @@ import (
 	"github.com/cloudreve/Cloudreve/v3/pkg/serializer"
 	"github.com/cloudreve/Cloudreve/v3/pkg/util"
 	"github.com/gin-contrib/sessions"
-	"github.com/gin-contrib/sessions/memstore"
-	"github.com/gin-contrib/sessions/redis"
 	"github.com/gin-gonic/gin"
 )
 
 // Store session存储
-var Store memstore.Store
+var Store sessions.Store
 
 // Session 初始化session
 func Session(secret string) gin.HandlerFunc {
 	// Redis设置不为空，且非测试模式时使用Redis
-	if conf.RedisConfig.Server != "" && gin.Mode() != gin.TestMode {
-		var err error
-		Store, err = redis.NewStoreWithDB(10, conf.RedisConfig.Network, conf.RedisConfig.Server, conf.RedisConfig.Password, conf.RedisConfig.DB, []byte(secret))
-		if err != nil {
-			util.Log().Panic("Failed to connect to Redis：%s", err)
-		}
-
-		util.Log().Info("Connect to Redis server %q.", conf.RedisConfig.Server)
-	} else {
-		Store = memstore.NewStore([]byte(secret))
-	}
+	Store = sessionstore.NewStore(cache.Store, []byte(secret))
 
 	sameSiteMode := http.SameSiteDefaultMode
 	switch strings.ToLower(conf.CORSConfig.SameSite) {
