@@ -45,7 +45,7 @@ func NewMonitor(task *model.Download, pool cluster.Pool, mqClient mq.MQ) {
 
 		monitor.notifier = mqClient.Subscribe(monitor.Task.GID, 0)
 	} else {
-		monitor.setErrorStatus(errors.New("节点不可用"))
+		monitor.setErrorStatus(errors.New("node not avaliable"))
 	}
 }
 
@@ -77,11 +77,12 @@ func (monitor *Monitor) Update() bool {
 
 	if err != nil {
 		monitor.retried++
-		util.Log().Warning("无法获取下载任务[%s]的状态，%s", monitor.Task.GID, err)
+		util.Log().Warning("Cannot get status of download task %q: %s", monitor.Task.GID, err)
 
 		// 十次重试后认定为任务失败
 		if monitor.retried > MAX_RETRY {
-			util.Log().Warning("无法获取下载任务[%s]的状态，超过最大重试次数限制，%s", monitor.Task.GID, err)
+			util.Log().Warning("Cannot get status of download task %q，exceed maximum retry threshold: %s",
+				monitor.Task.GID, err)
 			monitor.setErrorStatus(err)
 			monitor.RemoveTempFolder()
 			return true
@@ -93,7 +94,7 @@ func (monitor *Monitor) Update() bool {
 
 	// 磁力链下载需要跟随
 	if len(status.FollowedBy) > 0 {
-		util.Log().Debug("离线下载[%s]重定向至[%s]", monitor.Task.GID, status.FollowedBy[0])
+		util.Log().Debug("Redirected download task from %q to %q.", monitor.Task.GID, status.FollowedBy[0])
 		monitor.Task.GID = status.FollowedBy[0]
 		monitor.Task.Save()
 		return false
@@ -101,28 +102,28 @@ func (monitor *Monitor) Update() bool {
 
 	// 更新任务信息
 	if err := monitor.UpdateTaskInfo(status); err != nil {
-		util.Log().Warning("无法更新下载任务[%s]的任务信息[%s]，", monitor.Task.GID, err)
+		util.Log().Warning("Failed to update status of download task %q: %s", monitor.Task.GID, err)
 		monitor.setErrorStatus(err)
 		monitor.RemoveTempFolder()
 		return true
 	}
 
-	util.Log().Debug("离线下载[%s]更新状态[%s]", status.Gid, status.Status)
+	util.Log().Debug("Remote download %q status updated to %q.", status.Gid, status.Status)
 
-	switch status.Status {
-	case "complete":
+	switch common.GetStatus(status) {
+	case common.Complete, common.Seeding:
 		return monitor.Complete(task.TaskPoll)
-	case "error":
+	case common.Error:
 		return monitor.Error(status)
-	case "active", "waiting", "paused":
+	case common.Downloading, common.Ready, common.Paused:
 		return false
-	case "removed":
+	case common.Canceled:
 		monitor.Task.Status = common.Canceled
 		monitor.Task.Save()
 		monitor.RemoveTempFolder()
 		return true
 	default:
-		util.Log().Warning("下载任务[%s]返回未知状态信息[%s]，", monitor.Task.GID, status.Status)
+		util.Log().Warning("Download task %q returns unknown status %q.", monitor.Task.GID, status.Status)
 		return true
 	}
 }
@@ -132,7 +133,7 @@ func (monitor *Monitor) UpdateTaskInfo(status rpc.StatusInfo) error {
 	originSize := monitor.Task.TotalSize
 
 	monitor.Task.GID = status.Gid
-	monitor.Task.Status = common.GetStatus(status.Status)
+	monitor.Task.Status = common.GetStatus(status)
 
 	// 文件大小、已下载大小
 	total, err := strconv.ParseUint(status.TotalLength, 10, 64)
@@ -235,6 +236,40 @@ func (monitor *Monitor) RemoveTempFolder() {
 
 // Complete 完成下载，返回是否中断监控
 func (monitor *Monitor) Complete(pool task.Pool) bool {
+	// 未开始转存，提交转存任务
+	if monitor.Task.TaskID == 0 {
+		return monitor.transfer(pool)
+	}
+
+	// 做种完成
+	if common.GetStatus(monitor.Task.StatusInfo) == common.Complete {
+		transferTask, err := model.GetTasksByID(monitor.Task.TaskID)
+		if err != nil {
+			monitor.setErrorStatus(err)
+			monitor.RemoveTempFolder()
+			return true
+		}
+
+		// 转存完成，回收下载目录
+		if transferTask.Type == task.TransferTaskType && transferTask.Status >= task.Error {
+			job, err := task.NewRecycleTask(monitor.Task)
+			if err != nil {
+				monitor.setErrorStatus(err)
+				monitor.RemoveTempFolder()
+				return true
+			}
+
+			// 提交回收任务
+			pool.Submit(job)
+
+			return true
+		}
+	}
+
+	return false
+}
+
+func (monitor *Monitor) transfer(pool task.Pool) bool {
 	// 创建中转任务
 	file := make([]string, 0, len(monitor.Task.StatusInfo.Files))
 	sizes := make(map[string]uint64, len(monitor.Task.StatusInfo.Files))
@@ -269,7 +304,7 @@ func (monitor *Monitor) Complete(pool task.Pool) bool {
 	monitor.Task.TaskID = job.Model().ID
 	monitor.Task.Save()
 
-	return true
+	return false
 }
 
 func (monitor *Monitor) setErrorStatus(err error) {
