@@ -66,8 +66,7 @@ func NewRedisStore(size int, network, address, password, database string) *Redis
 					redis.DialPassword(password),
 				)
 				if err != nil {
-					util.Log().Warning("Failed to create Redis connection: %s", err)
-					return nil, err
+					util.Log().Panic("Failed to create Redis connection: %s", err)
 				}
 				return c, nil
 			},
@@ -215,3 +214,13 @@ func (store *RedisStore) DeleteAll() error {
 
 	return err
 }
+
+// Persist Dummy implementation
+func (store *RedisStore) Persist(path string) error {
+	return nil
+}
+
+// Restore dummy implementation
+func (store *RedisStore) Restore(path string) error {
+	return nil
+}
