@@ -360,7 +360,7 @@ func TestHookClearFileSize(t *testing.T) {
 		)
 		mock.ExpectBegin()
 		mock.ExpectExec("UPDATE(.+)files(.+)").
-			WithArgs(0, sqlmock.AnyArg(), 1, 10).
+			WithArgs("", 0, sqlmock.AnyArg(), 1, 10).
 			WillReturnResult(sqlmock.NewResult(1, 1))
 		mock.ExpectExec("UPDATE(.+)users(.+)").
 			WithArgs(10, sqlmock.AnyArg()).
@@ -394,7 +394,7 @@ func TestHookUpdateSourceName(t *testing.T) {
 		}
 		ctx := context.WithValue(context.Background(), fsctx.FileModelCtx, originFile)
 		mock.ExpectBegin()
-		mock.ExpectExec("UPDATE(.+)").WithArgs("new.txt", sqlmock.AnyArg(), 1).WillReturnResult(sqlmock.NewResult(1, 1))
+		mock.ExpectExec("UPDATE(.+)").WithArgs("", "new.txt", sqlmock.AnyArg(), 1).WillReturnResult(sqlmock.NewResult(1, 1))
 		mock.ExpectCommit()
 		err := HookUpdateSourceName(ctx, fs, nil)
 		asserts.NoError(mock.ExpectationsWereMet())
@@ -429,7 +429,7 @@ func TestGenericAfterUpdate(t *testing.T) {
 		fs.Handler = handlerMock
 		mock.ExpectBegin()
 		mock.ExpectExec("UPDATE(.+)files(.+)").
-			WithArgs(10, sqlmock.AnyArg(), 1, 0).
+			WithArgs("", 10, sqlmock.AnyArg(), 1, 0).
 			WillReturnResult(sqlmock.NewResult(1, 1))
 		mock.ExpectExec("UPDATE(.+)users(.+)").
 			WithArgs(10, sqlmock.AnyArg()).
@@ -462,7 +462,7 @@ func TestGenericAfterUpdate(t *testing.T) {
 
 		mock.ExpectBegin()
 		mock.ExpectExec("UPDATE(.+)").
-			WithArgs(10, sqlmock.AnyArg(), 1, 0).
+			WithArgs("", 10, sqlmock.AnyArg(), 1, 0).
 			WillReturnError(errors.New("error"))
 		mock.ExpectRollback()
 
@@ -473,27 +473,6 @@ func TestGenericAfterUpdate(t *testing.T) {
 	}
 }
 
-func TestHookGenerateThumb(t *testing.T) {
-	a := assert.New(t)
-	mockHandler := &FileHeaderMock{}
-	fs := &FileSystem{
-		User: &model.User{
-			Model: gorm.Model{ID: 1},
-		},
-		Handler: mockHandler,
-		Policy:  &model.Policy{Type: "local"},
-	}
-
-	mockHandler.On("Delete", testMock.Anything, []string{"1.txt._thumb"}).Return([]string{}, nil)
-	a.NoError(HookGenerateThumb(context.Background(), fs, &fsctx.FileStream{
-		Model: &model.File{
-			SourceName: "1.txt",
-		},
-	}))
-	fs.Recycle()
-	mockHandler.AssertExpectations(t)
-}
-
 func TestSlaveAfterUpload(t *testing.T) {
 	asserts := assert.New(t)
 	conf.SystemConfig.Mode = "slave"
@@ -625,7 +604,7 @@ func TestHookChunkUploaded(t *testing.T) {
 	}
 
 	mock.ExpectBegin()
-	mock.ExpectExec("UPDATE(.+)files(.+)").WithArgs(20, sqlmock.AnyArg(), 1, 0).WillReturnResult(sqlmock.NewResult(1, 1))
+	mock.ExpectExec("UPDATE(.+)files(.+)").WithArgs("", 20, sqlmock.AnyArg(), 1, 0).WillReturnResult(sqlmock.NewResult(1, 1))
 	mock.ExpectExec("UPDATE(.+)users(.+)").
 		WithArgs(20, sqlmock.AnyArg()).
 		WillReturnResult(sqlmock.NewResult(1, 1))
@@ -646,7 +625,7 @@ func TestHookChunkUploadFailed(t *testing.T) {
 	}
 
 	mock.ExpectBegin()
-	mock.ExpectExec("UPDATE(.+)files(.+)").WithArgs(10, sqlmock.AnyArg(), 1, 0).WillReturnResult(sqlmock.NewResult(1, 1))
+	mock.ExpectExec("UPDATE(.+)files(.+)").WithArgs("", 10, sqlmock.AnyArg(), 1, 0).WillReturnResult(sqlmock.NewResult(1, 1))
 	mock.ExpectExec("UPDATE(.+)users(.+)").
 		WithArgs(10, sqlmock.AnyArg()).
 		WillReturnResult(sqlmock.NewResult(1, 1))
@@ -704,3 +683,26 @@ func TestHookDeleteUploadSession(t *testing.T) {
 	_, ok := cache.Get(UploadSessionCachePrefix + "TestHookDeleteUploadSession")
 	a.False(ok)
 }
+func TestNewWebdavAfterUploadHook(t *testing.T) {
+	a := assert.New(t)
+	fs := &FileSystem{}
+	file := &fsctx.FileStream{
+		Model: &model.File{
+			Model: gorm.Model{ID: 1},
+		},
+	}
+
+	req, _ := http.NewRequest("get", "http://localhost", nil)
+	req.Header.Add("X-Oc-Mtime", "1681521402")
+	req.Header.Add("OC-Checksum", "checksum")
+	mock.ExpectBegin()
+	mock.ExpectExec("UPDATE(.+)files(.+)").WillReturnResult(sqlmock.NewResult(1, 1))
+	mock.ExpectCommit()
+	mock.ExpectBegin()
+	mock.ExpectExec("UPDATE(.+)files(.+)").WillReturnResult(sqlmock.NewResult(1, 1))
+	mock.ExpectCommit()
+	err := NewWebdavAfterUploadHook(req)(context.Background(), fs, file)
+	a.NoError(err)
+	a.NoError(mock.ExpectationsWereMet())
+
+}
