@@ -341,7 +341,6 @@ func (fs *FileSystem) listObjects(ctx context.Context, parent string, files []mo
 			ID:         hashid.HashID(subFolder.ID, hashid.FolderID),
 			Name:       subFolder.Name,
 			Path:       processedPath,
-			Pic:        "",
 			Size:       0,
 			Type:       "dir",
 			Date:       subFolder.UpdatedAt,
@@ -363,7 +362,7 @@ func (fs *FileSystem) listObjects(ctx context.Context, parent string, files []mo
 				ID:            hashid.HashID(file.ID, hashid.FileID),
 				Name:          file.Name,
 				Path:          processedPath,
-				Pic:           file.PicInfo,
+				Thumb:         file.ShouldLoadThumb(),
 				Size:          file.Size,
 				Type:          "file",
 				Date:          file.UpdatedAt,
