@@ -81,7 +81,7 @@ func (job *ImportTask) Do() {
 	// 查找存储策略
 	policy, err := model.GetPolicyByID(job.TaskProps.PolicyID)
 	if err != nil {
-		job.SetErrorMsg("找不到存储策略", err)
+		job.SetErrorMsg("Policy not exist.", err)
 		return
 	}
 
@@ -96,7 +96,7 @@ func (job *ImportTask) Do() {
 
 	fs.Policy = &policy
 	if err := fs.DispatchHandler(); err != nil {
-		job.SetErrorMsg("无法分发存储策略", err)
+		job.SetErrorMsg("Failed to dispatch policy.", err)
 		return
 	}
 
@@ -110,7 +110,7 @@ func (job *ImportTask) Do() {
 		true)
 	objects, err := fs.Handler.List(ctx, job.TaskProps.Src, job.TaskProps.Recursive)
 	if err != nil {
-		job.SetErrorMsg("无法列取文件", err)
+		job.SetErrorMsg("Failed to list files.", err)
 		return
 	}
 
@@ -126,7 +126,7 @@ func (job *ImportTask) Do() {
 			virtualPath := path.Join(job.TaskProps.Dst, object.RelativePath)
 			folder, err := fs.CreateDirectory(coxIgnoreConflict, virtualPath)
 			if err != nil {
-				util.Log().Warning("导入任务无法创建用户目录[%s], %s", virtualPath, err)
+				util.Log().Warning("Importing task cannot create user directory %q: %s", virtualPath, err)
 			} else if folder.ID > 0 {
 				pathCache[virtualPath] = folder
 			}
@@ -152,7 +152,7 @@ func (job *ImportTask) Do() {
 			} else {
 				folder, err := fs.CreateDirectory(context.Background(), virtualPath)
 				if err != nil {
-					util.Log().Warning("导入任务无法创建用户目录[%s], %s",
+					util.Log().Warning("Importing task cannot create user directory %q: %s",
 						virtualPath, err)
 					continue
 				}
@@ -163,10 +163,10 @@ func (job *ImportTask) Do() {
 			// 插入文件记录
 			_, err := fs.AddFile(context.Background(), parentFolder, &fileHeader)
 			if err != nil {
-				util.Log().Warning("导入任务无法创插入文件[%s], %s",
+				util.Log().Warning("Importing task cannot insert user file %q: %s",
 					object.RelativePath, err)
 				if err == filesystem.ErrInsufficientCapacity {
-					job.SetErrorMsg("容量不足", err)
+					job.SetErrorMsg("Insufficient storage capacity.", err)
 					return
 				}
 			}
