@@ -22,7 +22,7 @@ func CreatNestedFile(path string) (*os.File, error) {
 	if !Exists(basePath) {
 		err := os.MkdirAll(basePath, 0700)
 		if err != nil {
-			Log().Warning("无法创建目录，%s", err)
+			Log().Warning("Failed to create directory: %s", err)
 			return nil, err
 		}
 	}
