@@ -345,7 +345,7 @@ func (h *Handler) handlePut(w http.ResponseWriter, r *http.Request, fs *filesyst
 	fileName := path.Base(reqPath)
 	filePath := path.Dir(reqPath)
 	fileData := fsctx.FileStream{
-		MIMEType:    r.Header.Get("Content-Type"),
+		MimeType:    r.Header.Get("Content-Type"),
 		File:        r.Body,
 		Size:        fileSize,
 		Name:        fileName,
@@ -386,10 +386,12 @@ func (h *Handler) handlePut(w http.ResponseWriter, r *http.Request, fs *filesyst
 		fs.Use("AfterUploadCanceled", filesystem.HookDeleteTempFile)
 		fs.Use("AfterUploadCanceled", filesystem.HookCancelContext)
 		fs.Use("AfterUpload", filesystem.GenericAfterUpload)
-		fs.Use("AfterUpload", filesystem.HookGenerateThumb)
 		fs.Use("AfterValidateFailed", filesystem.HookDeleteTempFile)
 	}
 
+	// rclone 请求
+	fs.Use("AfterUpload", filesystem.NewWebdavAfterUploadHook(r))
+
 	// 执行上传
 	err = fs.Upload(ctx, &fileData)
 	if err != nil {
